cd ./0_data/
ls
[0m[01;31mGFP_OE_250926N_R1.fastq.gz[0m [01;31mrox2_OE_250926N_R1.fastq.gz[0m
[01;31mGFP_OE_250926N_R2.fastq.gz[0m [01;31mrox2_OE_250926N_R2.fastq.gz[0m
for i in `ls *_R1.fastq.gz`
do
prefix=${i%%_R1.fastq.gz}
name=${i%%_25*}
echo $name
fastp -i $i -o ${name}_R1.fq.gz -I ${prefix}_R2.fastq.gz -O ${name}_R2.fq.gz -w 50 -j ${name}.json -h ${name}.html --detect_adapter_for_pe
bowtie2 -t -q -p 50 --local --very-sensitive-local --no-mixed --no-discordant --no-unal --phred33 -X 2000 -x '/home/yhli/genome/dm6Bowtie2/dm6' -1 ${name}_R1.fq.gz -2 ${name}_R2.fq.gz -S ./${name}.sam
samtools view -@ 50 -F 0x904 -q 20 -b -h -o ${name}.bam ${name}.sam
sambamba markdup -r -t 50 ${name}.bam ${name}.rmdup.bam
samtools view -@ 50 -h ${name}.rmdup.bam | grep -v 'random'|grep -v 'chrUn'|grep -v 'chrM'|samtools view -@ 50 -bS -o ${name}.rmChr.bam
samtools sort -@ 50 ${name}.rmChr.bam > ${name}.final.bam
samtools index -@ 50 ${name}.final.bam
total=`echo $(($(zcat ${i} | wc -l )/2))`
map=`samtools view -@ 50 -c ${name}.bam`
rmdup=`samtools view -@ 50 -c ${name}.rmdup.bam`
final=`samtools view -@ 50 -c ${name}.final.bam`
echo -e "${name} ${total} ${map} ${rmdup} ${final}" >> mapping.log
rm ${name}.sam
rm ${name}.bam
rm ${name}.rmChr.bam
rm ${name}.rmdup.bam
done
GFP_OE
Detecting adapter sequence for read1...
>I7_Nextera_Transposase_1 | >Trans2_rc | >I7_Nextera_Transposase_1 | >Trans2_rc
CTGTCTCTTATACACATCTCCGAGCCCACGAGAC
Detecting adapter sequence for read2...
>I5_Nextera_Transposase_1 | >Trans1_rc | >I5_Nextera_Transposase_1 | >Trans1_rc
CTGTCTCTTATACACATCTGACGCTGCCGACGA
WARNING: fastp uses up to 16 threads although you specified 50
Read1 before filtering:
total reads: 21437850
total bases: 3215677500
Q20 bases: 3041184237(94.5737%)
Q30 bases: 2824348619(87.8306%)
Read2 before filtering:
total reads: 21437850
total bases: 3215677500
Q20 bases: 3146664392(97.8539%)
Q30 bases: 2994646853(93.1265%)
Read1 after filtering:
total reads: 21182137
total bases: 2357310971
Q20 bases: 2339405695(99.2404%)
Q30 bases: 2267885738(96.2065%)
Read2 after filtering:
total reads: 21182137
total bases: 2357820595
Q20 bases: 2322471304(98.5008%)
Q30 bases: 2225144751(94.3729%)
Filtering result:
reads passed filter: 42364274
reads failed due to low quality: 489316
reads failed due to too many N: 21974
reads failed due to too short: 136
reads with adapter trimmed: 28099246
bases trimmed due to adapters: 1656753510
Duplication rate: 19.0219%
Insert size peak (evaluated by paired-end reads): 65
JSON report: GFP_OE.json
HTML report: GFP_OE.html
fastp -i GFP_OE_250926N_R1.fastq.gz -o GFP_OE_R1.fq.gz -I GFP_OE_250926N_R2.fastq.gz -O GFP_OE_R2.fq.gz -w 50 -j GFP_OE.json -h GFP_OE.html --detect_adapter_for_pe
fastp v0.23.4, time used: 92 seconds
Time loading reference: 00:00:00
Time loading forward index: 00:00:00
Time loading mirror index: 00:00:00
Multiseed full-index search: 00:13:41
21182137 reads; of these:
21182137 (100.00%) were paired; of these:
8133888 (38.40%) aligned concordantly 0 times
9453759 (44.63%) aligned concordantly exactly 1 time
3594490 (16.97%) aligned concordantly >1 times
61.60% overall alignment rate
Time searching: 00:13:41
Overall time: 00:13:41
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
finding positions of the duplicate reads in the file...
sorted 10099542 end pairs
and 0 single ends (among them 0 unmatched pairs)
collecting indices of duplicate reads... done in 1156 ms
found 4808164 duplicates
collected list of positions in 0 min 33 sec
removing duplicates...
collected list of positions in 1 min 3 sec
[bam_sort_core] merging from 0 files and 50 in-memory blocks...
rox2_OE
Detecting adapter sequence for read1...
>I7_Nextera_Transposase_1 | >Trans2_rc | >I7_Nextera_Transposase_1 | >Trans2_rc
CTGTCTCTTATACACATCTCCGAGCCCACGAGAC
Detecting adapter sequence for read2...
>I5_Nextera_Transposase_1 | >Trans1_rc | >I5_Nextera_Transposase_1 | >Trans1_rc
CTGTCTCTTATACACATCTGACGCTGCCGACGA
WARNING: fastp uses up to 16 threads although you specified 50
Read1 before filtering:
total reads: 17852151
total bases: 2677822650
Q20 bases: 2533817930(94.6223%)
Q30 bases: 2356033905(87.9832%)
Read2 before filtering:
total reads: 17852151
total bases: 2677822650
Q20 bases: 2628370097(98.1533%)
Q30 bases: 2515635155(93.9433%)
Read1 after filtering:
total reads: 17680442
total bases: 1922737123
Q20 bases: 1911026019(99.3909%)
Q30 bases: 1863858583(96.9378%)
Read2 after filtering:
total reads: 17680442
total bases: 1923663379
Q20 bases: 1895872097(98.5553%)
Q30 bases: 1821084749(94.6675%)
Filtering result:
reads passed filter: 35360884
reads failed due to low quality: 295198
reads failed due to too many N: 44666
reads failed due to too short: 3554
reads with adapter trimmed: 23892708
bases trimmed due to adapters: 1470086534
Duplication rate: 38.3336%
Insert size peak (evaluated by paired-end reads): 63
JSON report: rox2_OE.json
HTML report: rox2_OE.html
fastp -i rox2_OE_250926N_R1.fastq.gz -o rox2_OE_R1.fq.gz -I rox2_OE_250926N_R2.fastq.gz -O rox2_OE_R2.fq.gz -w 50 -j rox2_OE.json -h rox2_OE.html --detect_adapter_for_pe
fastp v0.23.4, time used: 65 seconds
Time loading reference: 00:00:00
Time loading forward index: 00:00:00
Time loading mirror index: 00:00:00
Multiseed full-index search: 00:02:46
17680442 reads; of these:
17680442 (100.00%) were paired; of these:
14629554 (82.74%) aligned concordantly 0 times
2137968 (12.09%) aligned concordantly exactly 1 time
912920 (5.16%) aligned concordantly >1 times
17.26% overall alignment rate
Time searching: 00:02:46
Overall time: 00:02:46
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
finding positions of the duplicate reads in the file...
sorted 2241580 end pairs
and 0 single ends (among them 0 unmatched pairs)
collecting indices of duplicate reads... done in 433 ms
found 2631878 duplicates
collected list of positions in 0 min 7 sec
removing duplicates...
collected list of positions in 0 min 15 sec
[bam_sort_core] merging from 0 files and 50 in-memory blocks...
for i in `ls *_R1.fq.gz`
do
prefix=${i%%_R1.fq.gz}
name=${i%%_R1*gz}
echo $name
bowtie2 -t -q -p 50 --local --very-sensitive-local --no-mixed --no-discordant --no-unal --phred33 -X 2000 -x '/home/share/iGenome/Escherichia_coli_K_12_MG1655/NCBI/2001-10-15/Sequence/Bowtie2Index/genome' -1 ${name}_R1.fq.gz -2 ${name}_R2.fq.gz -S ./${name}.sam
samtools view -@ 50 -F 0x904 -q 20 -b -h -o ${name}.bam ${name}.sam
sambamba markdup -r -t 50 ${name}.bam ${name}.rmdup.bam
samtools view -@ 50 -h ${name}.rmdup.bam | grep -v 'random'|grep -v 'chrUn'|grep -v 'chrM'|samtools view -@ 50 -bS -o ${name}.rmChr.bam
samtools sort -@ 50 ${name}.rmChr.bam > ${name}_Ecoli.final.bam
samtools index -@ 50 ${name}_Ecoli.final.bam
total=`echo $(($(zcat ${i} | wc -l )/2))`
map=`samtools view -@ 50 -c ${name}.bam`
rmdup=`samtools view -@ 50 -c ${name}.rmdup.bam`
final=`samtools view -@ 50 -c ${name}_Ecoli.final.bam`
echo -e "${name} ${total} ${map} ${rmdup} ${final}" >> mapping_Ecoli.log
rm ${name}.sam
rm ${name}.bam
rm ${name}.rmChr.bam
rm ${name}.rmdup.bam
done
GFP_OE
Time loading reference: 00:00:00
Time loading forward index: 00:00:00
Time loading mirror index: 00:00:00
Multiseed full-index search: 00:02:38
21182137 reads; of these:
21182137 (100.00%) were paired; of these:
20787439 (98.14%) aligned concordantly 0 times
376255 (1.78%) aligned concordantly exactly 1 time
18443 (0.09%) aligned concordantly >1 times
1.86% overall alignment rate
Time searching: 00:02:38
Overall time: 00:02:38
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
finding positions of the duplicate reads in the file...
sorted 382007 end pairs
and 0 single ends (among them 0 unmatched pairs)
collecting indices of duplicate reads... done in 57 ms
found 93256 duplicates
collected list of positions in 0 min 1 sec
removing duplicates...
collected list of positions in 0 min 2 sec
[bam_sort_core] merging from 0 files and 50 in-memory blocks...
rox2_OE
Time loading reference: 00:00:00
Time loading forward index: 00:00:00
Time loading mirror index: 00:00:00
Multiseed full-index search: 00:02:11
17680442 reads; of these:
17680442 (100.00%) were paired; of these:
17463014 (98.77%) aligned concordantly 0 times
206845 (1.17%) aligned concordantly exactly 1 time
10583 (0.06%) aligned concordantly >1 times
1.23% overall alignment rate
Time searching: 00:02:11
Overall time: 00:02:11
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
finding positions of the duplicate reads in the file...
sorted 209852 end pairs
and 0 single ends (among them 0 unmatched pairs)
collecting indices of duplicate reads... done in 33 ms
found 130690 duplicates
collected list of positions in 0 min 0 sec
removing duplicates...
collected list of positions in 0 min 1 sec
[bam_sort_core] merging from 0 files and 50 in-memory blocks...
cat ./mapping.log
GFP_OE 42875700 20199084 15390920 14656476
rox2_OE 35704302 4483160 1851282 1687200
cat ./mapping_Ecoli.log
GFP_OE 42364274 764014 670758 670758
rox2_OE 35360884 419704 289014 289014
for i in `ls *_Ecoli.final.bam`
do
name=${i%_Ecoli.final.bam}
echo $name
scaleFactor=`awk -v name="${name}" '$1==name {print 10000000/$5}' mapping_Ecoli.log`
echo $scaleFactor
bedtools genomecov -bg -scale $scaleFactor -ibam ${name}.final.bam > ${name}_norm.bedgraph
bamCoverage -bs 20 --smoothLength 50 -p 50 -b ${name}.final.bam -o ${name}_20.bw --normalizeUsing None --scaleFactor $scaleFactor
done
GFP_OE
14.9085
bamFilesList: ['GFP_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: 50
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
rox2_OE
34.6004
bamFilesList: ['rox2_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: 50
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
fastqc -t 50 *.fastq.gz
multiqc ./
application/gzip
application/gzip
application/gzip
Started analysis of GFP_OE_250926N_R1.fastq.gz
application/gzip
Started analysis of GFP_OE_250926N_R2.fastq.gz
Started analysis of rox2_OE_250926N_R1.fastq.gz
Started analysis of rox2_OE_250926N_R2.fastq.gz
Approx 5% complete for rox2_OE_250926N_R1.fastq.gz
Approx 5% complete for rox2_OE_250926N_R2.fastq.gz
Approx 5% complete for GFP_OE_250926N_R2.fastq.gz
Approx 5% complete for GFP_OE_250926N_R1.fastq.gz
Approx 10% complete for rox2_OE_250926N_R1.fastq.gz
Approx 10% complete for rox2_OE_250926N_R2.fastq.gz
Approx 10% complete for GFP_OE_250926N_R2.fastq.gz
Approx 10% complete for GFP_OE_250926N_R1.fastq.gz
Approx 15% complete for rox2_OE_250926N_R1.fastq.gz
Approx 15% complete for rox2_OE_250926N_R2.fastq.gz
Approx 15% complete for GFP_OE_250926N_R2.fastq.gz
Approx 15% complete for GFP_OE_250926N_R1.fastq.gz
Approx 20% complete for rox2_OE_250926N_R1.fastq.gz
Approx 20% complete for rox2_OE_250926N_R2.fastq.gz
Approx 20% complete for GFP_OE_250926N_R2.fastq.gz
Approx 25% complete for rox2_OE_250926N_R2.fastq.gz
Approx 25% complete for rox2_OE_250926N_R1.fastq.gz
Approx 20% complete for GFP_OE_250926N_R1.fastq.gz
Approx 25% complete for GFP_OE_250926N_R2.fastq.gz
Approx 30% complete for rox2_OE_250926N_R2.fastq.gz
Approx 30% complete for rox2_OE_250926N_R1.fastq.gz
Approx 25% complete for GFP_OE_250926N_R1.fastq.gz
Approx 35% complete for rox2_OE_250926N_R2.fastq.gz
Approx 35% complete for rox2_OE_250926N_R1.fastq.gz
Approx 30% complete for GFP_OE_250926N_R2.fastq.gz
Approx 30% complete for GFP_OE_250926N_R1.fastq.gz
Approx 40% complete for rox2_OE_250926N_R2.fastq.gz
Approx 40% complete for rox2_OE_250926N_R1.fastq.gz
Approx 35% complete for GFP_OE_250926N_R2.fastq.gz
Approx 35% complete for GFP_OE_250926N_R1.fastq.gz
Approx 45% complete for rox2_OE_250926N_R2.fastq.gz
Approx 45% complete for rox2_OE_250926N_R1.fastq.gz
Approx 40% complete for GFP_OE_250926N_R2.fastq.gz
Approx 40% complete for GFP_OE_250926N_R1.fastq.gz
Approx 50% complete for rox2_OE_250926N_R2.fastq.gz
Approx 50% complete for rox2_OE_250926N_R1.fastq.gz
Approx 45% complete for GFP_OE_250926N_R2.fastq.gz
Approx 55% complete for rox2_OE_250926N_R2.fastq.gz
Approx 55% complete for rox2_OE_250926N_R1.fastq.gz
Approx 45% complete for GFP_OE_250926N_R1.fastq.gz
Approx 50% complete for GFP_OE_250926N_R2.fastq.gz
Approx 60% complete for rox2_OE_250926N_R2.fastq.gz
Approx 60% complete for rox2_OE_250926N_R1.fastq.gz
Approx 50% complete for GFP_OE_250926N_R1.fastq.gz
Approx 65% complete for rox2_OE_250926N_R2.fastq.gz
Approx 55% complete for GFP_OE_250926N_R2.fastq.gz
Approx 65% complete for rox2_OE_250926N_R1.fastq.gz
Approx 55% complete for GFP_OE_250926N_R1.fastq.gz
Approx 70% complete for rox2_OE_250926N_R2.fastq.gz
Approx 70% complete for rox2_OE_250926N_R1.fastq.gz
Approx 60% complete for GFP_OE_250926N_R2.fastq.gz
Approx 60% complete for GFP_OE_250926N_R1.fastq.gz
Approx 75% complete for rox2_OE_250926N_R2.fastq.gz
Approx 75% complete for rox2_OE_250926N_R1.fastq.gz
Approx 65% complete for GFP_OE_250926N_R2.fastq.gz
Approx 80% complete for rox2_OE_250926N_R2.fastq.gz
Approx 65% complete for GFP_OE_250926N_R1.fastq.gz
Approx 80% complete for rox2_OE_250926N_R1.fastq.gz
Approx 70% complete for GFP_OE_250926N_R2.fastq.gz
Approx 85% complete for rox2_OE_250926N_R2.fastq.gz
Approx 85% complete for rox2_OE_250926N_R1.fastq.gz
Approx 70% complete for GFP_OE_250926N_R1.fastq.gz
Approx 90% complete for rox2_OE_250926N_R2.fastq.gz
Approx 75% complete for GFP_OE_250926N_R2.fastq.gz
Approx 90% complete for rox2_OE_250926N_R1.fastq.gz
Approx 75% complete for GFP_OE_250926N_R1.fastq.gz
Approx 95% complete for rox2_OE_250926N_R2.fastq.gz
Approx 95% complete for rox2_OE_250926N_R1.fastq.gz
Approx 80% complete for GFP_OE_250926N_R2.fastq.gz
Analysis complete for rox2_OE_250926N_R2.fastq.gz
Approx 80% complete for GFP_OE_250926N_R1.fastq.gz
Analysis complete for rox2_OE_250926N_R1.fastq.gz
Approx 85% complete for GFP_OE_250926N_R2.fastq.gz
Approx 85% complete for GFP_OE_250926N_R1.fastq.gz
Approx 90% complete for GFP_OE_250926N_R2.fastq.gz
Approx 90% complete for GFP_OE_250926N_R1.fastq.gz
Approx 95% complete for GFP_OE_250926N_R2.fastq.gz
Approx 95% complete for GFP_OE_250926N_R1.fastq.gz
Analysis complete for GFP_OE_250926N_R2.fastq.gz
Analysis complete for GFP_OE_250926N_R1.fastq.gz
[38;5;208m///[0m ]8;id=685770;https://multiqc.info\[1mMultiQC[0m]8;;\ ๐ [2m| v1.17[0m
[34m| multiqc[0m | Search path : /home/yhli/result/Dm-roX2OE-ATAC-202510/0_data
[2K[34m|[0m [34msearching[0m | [38;5;70mโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโโ[0m [35m100%[0m [32m34/34[0m m [35m 29%[0m [32m10/34[0m [2m./GFP_OE_20.bw[0m
[?25h[34m| fastqc[0m | Found 4 reports
[34m| multiqc[0m | Report : multiqc_report.html
[34m| multiqc[0m | Data : multiqc_data
[34m| multiqc[0m | MultiQC complete
bamCoverage & bamCompare
cd ../1_macs
for i in `ls ../0_data/*.final.bam`
do
name=${i%%.final.bam}
name=${name##*/}
echo $name
bamCoverage -bs 20 -p 50 -b $i -o ${name}_20_RPKM.bw --normalizeUsing RPKM
# bamCoverage -bs 20 -p 50 -b $i -o ${name}_20.bw --normalizeUsing None
bamCoverage -bs 20 -p 50 -b $i -o ${name}_20_RPKM.bdg --normalizeUsing RPKM --outFileFormat bedgraph
# bamCoverage -bs 20 -p 50 -b $i -o ${name}_20.bdg --normalizeUsing None --outFileFormat bedgraph
done
GFP_OE_Ecoli
normalization: RPKM
bamFilesList: ['../0_data/GFP_OE_Ecoli.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
normalization: RPKM
bamFilesList: ['../0_data/GFP_OE_Ecoli.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
GFP_OE
normalization: RPKM
bamFilesList: ['../0_data/GFP_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
normalization: RPKM
bamFilesList: ['../0_data/GFP_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
rox2_OE_Ecoli
normalization: RPKM
bamFilesList: ['../0_data/rox2_OE_Ecoli.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
normalization: RPKM
bamFilesList: ['../0_data/rox2_OE_Ecoli.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
rox2_OE
normalization: RPKM
bamFilesList: ['../0_data/rox2_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
normalization: RPKM
bamFilesList: ['../0_data/rox2_OE.final.bam']
binLength: 20
numberOfSamples: None
blackListFileName: None
skipZeroOverZero: False
bed_and_bin: False
genomeChunkSize: None
defaultFragmentLength: read length
numberOfProcessors: 50
verbose: False
region: None
bedFile: None
minMappingQuality: None
ignoreDuplicates: False
chrsToSkip: []
stepSize: 20
center_read: False
samFlag_include: None
samFlag_exclude: None
minFragmentLength: 0
maxFragmentLength: 0
zerosToNans: False
smoothLength: None
save_data: False
out_file_for_raw_data: None
maxPairedFragmentLength: 1000
computeMatrix scale-regions -p 50 -R '/home/share/chipRef/dm6_genes.bed' --missingDataAsZero -a 3000 -b 3000 -m 5000 -bs 20 -S './GFP_OE_20_RPKM.bw' './rox2_OE_20_RPKM.bw' --samplesLabel GFP-OE roX2-OE -o matrix.mat.gz
plotHeatmap -m matrix.mat.gz -o heatmap_RPKM.png --colorMap coolwarm --heatmapHeight 12 --heatmapWidth 6 --perGroup
Skipping NM_001015101, due to being absent in the computeMatrix output.
Skipping NM_001015100, due to being absent in the computeMatrix output.
Skipping NM_001110584, due to being absent in the computeMatrix output.
Skipping NR_133556, due to being absent in the computeMatrix output.
Skipping NR_133556_r1, due to being absent in the computeMatrix output.
Skipping NR_133556_r2, due to being absent in the computeMatrix output.
Skipping NR_133555, due to being absent in the computeMatrix output.
Skipping NR_133555_r1, due to being absent in the computeMatrix output.
Skipping NR_133555_r2, due to being absent in the computeMatrix output.
Skipping NR_133554, due to being absent in the computeMatrix output.
Skipping NR_133554_r1, due to being absent in the computeMatrix output.
Skipping NR_133554_r2, due to being absent in the computeMatrix output.
Skipping NR_133553, due to being absent in the computeMatrix output.
Skipping NR_133553_r1, due to being absent in the computeMatrix output.
Skipping NR_133552_r2, due to being absent in the computeMatrix output.
Skipping NR_133552_r3, due to being absent in the computeMatrix output.
Skipping NR_133552_r4, due to being absent in the computeMatrix output.
Skipping NR_133551, due to being absent in the computeMatrix output.
Skipping NR_133551_r1, due to being absent in the computeMatrix output.
Skipping NR_133551_r2, due to being absent in the computeMatrix output.
Skipping NR_133550, due to being absent in the computeMatrix output.
Skipping NR_133550_r1, due to being absent in the computeMatrix output.
Skipping NR_133550_r2, due to being absent in the computeMatrix output.
Skipping NR_133549, due to being absent in the computeMatrix output.
Skipping NR_133549_r1, due to being absent in the computeMatrix output.
Skipping NR_133545_r2, due to being absent in the computeMatrix output.
Skipping NR_133545_r3, due to being absent in the computeMatrix output.
Skipping NR_133545_r4, due to being absent in the computeMatrix output.
Skipping NR_133560, due to being absent in the computeMatrix output.
Skipping NR_133559, due to being absent in the computeMatrix output.
Skipping NR_133559_r1, due to being absent in the computeMatrix output.
Skipping NR_133559_r2, due to being absent in the computeMatrix output.
Skipping NR_133558, due to being absent in the computeMatrix output.
Skipping NR_133557_r2, due to being absent in the computeMatrix output.
Skipping NR_133557_r3, due to being absent in the computeMatrix output.
Skipping NR_133557_r4, due to being absent in the computeMatrix output.
Skipping NR_133562, due to being absent in the computeMatrix output.
Skipping NR_133561_r2, due to being absent in the computeMatrix output.
Skipping NR_133561_r3, due to being absent in the computeMatrix output.
Skipping NR_133561_r4, due to being absent in the computeMatrix output.
Skipping NR_133560_r1, due to being absent in the computeMatrix output.
Skipping NR_133560_r2, due to being absent in the computeMatrix output.
Skipping NR_156799_r3, due to being absent in the computeMatrix output.
Skipping NR_156799_r4, due to being absent in the computeMatrix output.
Skipping NR_156798_r3, due to being absent in the computeMatrix output.
Skipping NR_156798_r4, due to being absent in the computeMatrix output.
Skipping NR_163218_r3, due to being absent in the computeMatrix output.
Skipping NR_163218_r4, due to being absent in the computeMatrix output.
Skipping NR_163217_r3, due to being absent in the computeMatrix output.
Skipping NR_163217_r4, due to being absent in the computeMatrix output.
Skipping NR_163216_r3, due to being absent in the computeMatrix output.
Skipping NR_163216_r4, due to being absent in the computeMatrix output.
Skipping NM_001110608, due to being absent in the computeMatrix output.
Skipping NR_133552_r5, due to being absent in the computeMatrix output.
Skipping NR_133545_r5, due to being absent in the computeMatrix output.
Skipping NR_133557_r5, due to being absent in the computeMatrix output.
Skipping NR_133561_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r6, due to being absent in the computeMatrix output.
Skipping NR_133545_r6, due to being absent in the computeMatrix output.
Skipping NR_133557_r6, due to being absent in the computeMatrix output.
Skipping NR_133561_r6, due to being absent in the computeMatrix output.
Skipping NR_048533, due to being absent in the computeMatrix output.
Skipping NR_156799_r5, due to being absent in the computeMatrix output.
Skipping NR_156798_r5, due to being absent in the computeMatrix output.
Skipping NR_163218_r5, due to being absent in the computeMatrix output.
Skipping NR_163217_r5, due to being absent in the computeMatrix output.
Skipping NR_163216_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r7, due to being absent in the computeMatrix output.
Skipping NR_133545_r7, due to being absent in the computeMatrix output.
Skipping NR_133557_r7, due to being absent in the computeMatrix output.
Skipping NR_133561_r7, due to being absent in the computeMatrix output.
Skipping NR_156799_r6, due to being absent in the computeMatrix output.
Skipping NR_156798_r6, due to being absent in the computeMatrix output.
Skipping NR_163218_r6, due to being absent in the computeMatrix output.
Skipping NR_163217_r6, due to being absent in the computeMatrix output.
Skipping NR_163216_r6, due to being absent in the computeMatrix output.
Skipping NR_133552_r8, due to being absent in the computeMatrix output.
Skipping NR_133545_r8, due to being absent in the computeMatrix output.
Skipping NR_133557_r8, due to being absent in the computeMatrix output.
Skipping NR_133561_r8, due to being absent in the computeMatrix output.
Skipping NR_133556_r3, due to being absent in the computeMatrix output.
Skipping NR_133552_r9, due to being absent in the computeMatrix output.
Skipping NR_133551_r3, due to being absent in the computeMatrix output.
Skipping NR_133545_r9, due to being absent in the computeMatrix output.
Skipping NR_133560_r3, due to being absent in the computeMatrix output.
Skipping NR_133557_r9, due to being absent in the computeMatrix output.
Skipping NR_133561_r9, due to being absent in the computeMatrix output.
Skipping NR_156799_r7, due to being absent in the computeMatrix output.
Skipping NR_156798_r7, due to being absent in the computeMatrix output.
Skipping NR_163218_r7, due to being absent in the computeMatrix output.
Skipping NR_163217_r7, due to being absent in the computeMatrix output.
Skipping NR_163216_r7, due to being absent in the computeMatrix output.
Skipping NR_133552_r10, due to being absent in the computeMatrix output.
Skipping NR_133545_r10, due to being absent in the computeMatrix output.
Skipping NR_133557_r10, due to being absent in the computeMatrix output.
Skipping NR_133561_r10, due to being absent in the computeMatrix output.
Skipping NR_133557_r11, due to being absent in the computeMatrix output.
Skipping NR_133556_r4, due to being absent in the computeMatrix output.
Skipping NR_133552_r11, due to being absent in the computeMatrix output.
Skipping NR_133551_r4, due to being absent in the computeMatrix output.
Skipping NR_133545_r11, due to being absent in the computeMatrix output.
Skipping NR_133560_r4, due to being absent in the computeMatrix output.
Skipping NR_133561_r11, due to being absent in the computeMatrix output.
Skipping NR_156799_r8, due to being absent in the computeMatrix output.
Skipping NR_156798_r8, due to being absent in the computeMatrix output.
Skipping NR_163218_r8, due to being absent in the computeMatrix output.
Skipping NR_163217_r8, due to being absent in the computeMatrix output.
Skipping NR_163216_r8, due to being absent in the computeMatrix output.
Skipping NR_133557_r12, due to being absent in the computeMatrix output.
Skipping NR_133556_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r12, due to being absent in the computeMatrix output.
Skipping NR_133551_r5, due to being absent in the computeMatrix output.
Skipping NR_133545_r12, due to being absent in the computeMatrix output.
Skipping NR_133560_r5, due to being absent in the computeMatrix output.
Skipping NR_133561_r12, due to being absent in the computeMatrix output.
Skipping NM_001144069_r1, due to being absent in the computeMatrix output.
Skipping NR_133557_r13, due to being absent in the computeMatrix output.
Skipping NR_133556_r6, due to being absent in the computeMatrix output.
Skipping NR_133552_r13, due to being absent in the computeMatrix output.
Skipping NR_133551_r6, due to being absent in the computeMatrix output.
Skipping NR_133545_r13, due to being absent in the computeMatrix output.
Skipping NR_133560_r6, due to being absent in the computeMatrix output.
Skipping NR_133561_r13, due to being absent in the computeMatrix output.
Skipping NR_156799_r9, due to being absent in the computeMatrix output.
Skipping NR_156798_r9, due to being absent in the computeMatrix output.
Skipping NR_163218_r9, due to being absent in the computeMatrix output.
Skipping NR_163217_r9, due to being absent in the computeMatrix output.
Skipping NR_163216_r9, due to being absent in the computeMatrix output.
Skipping NM_001316662_r1, due to being absent in the computeMatrix output.
Skipping NR_026600_r1, due to being absent in the computeMatrix output.
Skipping NR_133547_r1, due to being absent in the computeMatrix output.
Skipping NR_125439_r1, due to being absent in the computeMatrix output.
Skipping NR_026603_r1, due to being absent in the computeMatrix output.
Skipping NR_026602_r1, due to being absent in the computeMatrix output.
Skipping NR_125438_r1, due to being absent in the computeMatrix output.
Skipping NR_026605, due to being absent in the computeMatrix output.
Skipping NR_026612, due to being absent in the computeMatrix output.
Skipping NR_026627, due to being absent in the computeMatrix output.
Skipping NM_001110696, due to being absent in the computeMatrix output.
Skipping NR_026633, due to being absent in the computeMatrix output.
Skipping NR_048534, due to being absent in the computeMatrix output.
computeMatrix scale-regions -p 50 -R '/home/share/chipRef/dm6_genes.bed' --missingDataAsZero -a 3000 -b 3000 -m 5000 -bs 20 -S '../0_data/GFP_OE_20.bw' '../0_data/rox2_OE_20.bw' --samplesLabel GFP-OE roX2-OE -o matrix.mat.gz
plotHeatmap -m matrix.mat.gz -o heatmap.png --colorMap coolwarm --heatmapHeight 12 --heatmapWidth 6 --perGroup
Skipping NM_001015101, due to being absent in the computeMatrix output.
Skipping NM_001015100, due to being absent in the computeMatrix output.
Skipping NM_001110584, due to being absent in the computeMatrix output.
Skipping NR_133556, due to being absent in the computeMatrix output.
Skipping NR_133556_r1, due to being absent in the computeMatrix output.
Skipping NR_133556_r2, due to being absent in the computeMatrix output.
Skipping NR_133555, due to being absent in the computeMatrix output.
Skipping NR_133555_r1, due to being absent in the computeMatrix output.
Skipping NR_133555_r2, due to being absent in the computeMatrix output.
Skipping NR_133554, due to being absent in the computeMatrix output.
Skipping NR_133554_r1, due to being absent in the computeMatrix output.
Skipping NR_133554_r2, due to being absent in the computeMatrix output.
Skipping NR_133553, due to being absent in the computeMatrix output.
Skipping NR_133553_r1, due to being absent in the computeMatrix output.
Skipping NR_133552_r2, due to being absent in the computeMatrix output.
Skipping NR_133552_r3, due to being absent in the computeMatrix output.
Skipping NR_133552_r4, due to being absent in the computeMatrix output.
Skipping NR_133551, due to being absent in the computeMatrix output.
Skipping NR_133551_r1, due to being absent in the computeMatrix output.
Skipping NR_133551_r2, due to being absent in the computeMatrix output.
Skipping NR_133550, due to being absent in the computeMatrix output.
Skipping NR_133550_r1, due to being absent in the computeMatrix output.
Skipping NR_133550_r2, due to being absent in the computeMatrix output.
Skipping NR_133549, due to being absent in the computeMatrix output.
Skipping NR_133549_r1, due to being absent in the computeMatrix output.
Skipping NR_133545_r2, due to being absent in the computeMatrix output.
Skipping NR_133545_r3, due to being absent in the computeMatrix output.
Skipping NR_133545_r4, due to being absent in the computeMatrix output.
Skipping NR_133560, due to being absent in the computeMatrix output.
Skipping NR_133559, due to being absent in the computeMatrix output.
Skipping NR_133559_r1, due to being absent in the computeMatrix output.
Skipping NR_133559_r2, due to being absent in the computeMatrix output.
Skipping NR_133558, due to being absent in the computeMatrix output.
Skipping NR_133557_r2, due to being absent in the computeMatrix output.
Skipping NR_133557_r3, due to being absent in the computeMatrix output.
Skipping NR_133557_r4, due to being absent in the computeMatrix output.
Skipping NR_133562, due to being absent in the computeMatrix output.
Skipping NR_133561_r2, due to being absent in the computeMatrix output.
Skipping NR_133561_r3, due to being absent in the computeMatrix output.
Skipping NR_133561_r4, due to being absent in the computeMatrix output.
Skipping NR_133560_r1, due to being absent in the computeMatrix output.
Skipping NR_133560_r2, due to being absent in the computeMatrix output.
Skipping NR_156799_r3, due to being absent in the computeMatrix output.
Skipping NR_156799_r4, due to being absent in the computeMatrix output.
Skipping NR_156798_r3, due to being absent in the computeMatrix output.
Skipping NR_156798_r4, due to being absent in the computeMatrix output.
Skipping NR_163218_r3, due to being absent in the computeMatrix output.
Skipping NR_163218_r4, due to being absent in the computeMatrix output.
Skipping NR_163217_r3, due to being absent in the computeMatrix output.
Skipping NR_163217_r4, due to being absent in the computeMatrix output.
Skipping NR_163216_r3, due to being absent in the computeMatrix output.
Skipping NR_163216_r4, due to being absent in the computeMatrix output.
Skipping NM_001110608, due to being absent in the computeMatrix output.
Skipping NR_133552_r5, due to being absent in the computeMatrix output.
Skipping NR_133545_r5, due to being absent in the computeMatrix output.
Skipping NR_133557_r5, due to being absent in the computeMatrix output.
Skipping NR_133561_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r6, due to being absent in the computeMatrix output.
Skipping NR_133545_r6, due to being absent in the computeMatrix output.
Skipping NR_133557_r6, due to being absent in the computeMatrix output.
Skipping NR_133561_r6, due to being absent in the computeMatrix output.
Skipping NR_048533, due to being absent in the computeMatrix output.
Skipping NR_156799_r5, due to being absent in the computeMatrix output.
Skipping NR_156798_r5, due to being absent in the computeMatrix output.
Skipping NR_163218_r5, due to being absent in the computeMatrix output.
Skipping NR_163217_r5, due to being absent in the computeMatrix output.
Skipping NR_163216_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r7, due to being absent in the computeMatrix output.
Skipping NR_133545_r7, due to being absent in the computeMatrix output.
Skipping NR_133557_r7, due to being absent in the computeMatrix output.
Skipping NR_133561_r7, due to being absent in the computeMatrix output.
Skipping NR_156799_r6, due to being absent in the computeMatrix output.
Skipping NR_156798_r6, due to being absent in the computeMatrix output.
Skipping NR_163218_r6, due to being absent in the computeMatrix output.
Skipping NR_163217_r6, due to being absent in the computeMatrix output.
Skipping NR_163216_r6, due to being absent in the computeMatrix output.
Skipping NR_133552_r8, due to being absent in the computeMatrix output.
Skipping NR_133545_r8, due to being absent in the computeMatrix output.
Skipping NR_133557_r8, due to being absent in the computeMatrix output.
Skipping NR_133561_r8, due to being absent in the computeMatrix output.
Skipping NR_133556_r3, due to being absent in the computeMatrix output.
Skipping NR_133552_r9, due to being absent in the computeMatrix output.
Skipping NR_133551_r3, due to being absent in the computeMatrix output.
Skipping NR_133545_r9, due to being absent in the computeMatrix output.
Skipping NR_133560_r3, due to being absent in the computeMatrix output.
Skipping NR_133557_r9, due to being absent in the computeMatrix output.
Skipping NR_133561_r9, due to being absent in the computeMatrix output.
Skipping NR_156799_r7, due to being absent in the computeMatrix output.
Skipping NR_156798_r7, due to being absent in the computeMatrix output.
Skipping NR_163218_r7, due to being absent in the computeMatrix output.
Skipping NR_163217_r7, due to being absent in the computeMatrix output.
Skipping NR_163216_r7, due to being absent in the computeMatrix output.
Skipping NR_133552_r10, due to being absent in the computeMatrix output.
Skipping NR_133545_r10, due to being absent in the computeMatrix output.
Skipping NR_133557_r10, due to being absent in the computeMatrix output.
Skipping NR_133561_r10, due to being absent in the computeMatrix output.
Skipping NR_133557_r11, due to being absent in the computeMatrix output.
Skipping NR_133556_r4, due to being absent in the computeMatrix output.
Skipping NR_133552_r11, due to being absent in the computeMatrix output.
Skipping NR_133551_r4, due to being absent in the computeMatrix output.
Skipping NR_133545_r11, due to being absent in the computeMatrix output.
Skipping NR_133560_r4, due to being absent in the computeMatrix output.
Skipping NR_133561_r11, due to being absent in the computeMatrix output.
Skipping NR_156799_r8, due to being absent in the computeMatrix output.
Skipping NR_156798_r8, due to being absent in the computeMatrix output.
Skipping NR_163218_r8, due to being absent in the computeMatrix output.
Skipping NR_163217_r8, due to being absent in the computeMatrix output.
Skipping NR_163216_r8, due to being absent in the computeMatrix output.
Skipping NR_133557_r12, due to being absent in the computeMatrix output.
Skipping NR_133556_r5, due to being absent in the computeMatrix output.
Skipping NR_133552_r12, due to being absent in the computeMatrix output.
Skipping NR_133551_r5, due to being absent in the computeMatrix output.
Skipping NR_133545_r12, due to being absent in the computeMatrix output.
Skipping NR_133560_r5, due to being absent in the computeMatrix output.
Skipping NR_133561_r12, due to being absent in the computeMatrix output.
Skipping NM_001144069_r1, due to being absent in the computeMatrix output.
Skipping NR_133557_r13, due to being absent in the computeMatrix output.
Skipping NR_133556_r6, due to being absent in the computeMatrix output.
Skipping NR_133552_r13, due to being absent in the computeMatrix output.
Skipping NR_133551_r6, due to being absent in the computeMatrix output.
Skipping NR_133545_r13, due to being absent in the computeMatrix output.
Skipping NR_133560_r6, due to being absent in the computeMatrix output.
Skipping NR_133561_r13, due to being absent in the computeMatrix output.
Skipping NR_156799_r9, due to being absent in the computeMatrix output.
Skipping NR_156798_r9, due to being absent in the computeMatrix output.
Skipping NR_163218_r9, due to being absent in the computeMatrix output.
Skipping NR_163217_r9, due to being absent in the computeMatrix output.
Skipping NR_163216_r9, due to being absent in the computeMatrix output.
Skipping NM_001316662_r1, due to being absent in the computeMatrix output.
Skipping NR_026600_r1, due to being absent in the computeMatrix output.
Skipping NR_133547_r1, due to being absent in the computeMatrix output.
Skipping NR_125439_r1, due to being absent in the computeMatrix output.
Skipping NR_026603_r1, due to being absent in the computeMatrix output.
Skipping NR_026602_r1, due to being absent in the computeMatrix output.
Skipping NR_125438_r1, due to being absent in the computeMatrix output.
Skipping NR_026605, due to being absent in the computeMatrix output.
Skipping NR_026612, due to being absent in the computeMatrix output.
Skipping NR_026627, due to being absent in the computeMatrix output.
Skipping NM_001110696, due to being absent in the computeMatrix output.
Skipping NR_026633, due to being absent in the computeMatrix output.
Skipping NR_048534, due to being absent in the computeMatrix output.
macs3 callpeak -t '../0_data/GFP_OE.final.bam' -g dm -n GFP_OE --shift -100 --extsize 200 --nomodel -B -f BAMPE
macs3 callpeak -t '../0_data/rox2_OE.final.bam' -g dm -n roX2_OE --shift -100 --extsize 200 --nomodel -B -f BAMPE
INFO @ 13 Nov 2025 15:26:39: [44 MB]
# Command line: callpeak -t ../0_data/GFP_OE.final.bam -g dm -n GFP_OE --shift -100 --extsize 200 --nomodel -B -f BAMPE
# ARGUMENTS LIST:
# name = GFP_OE
# format = BAMPE
# ChIP-seq file = ['../0_data/GFP_OE.final.bam']
# control file = None
# effective genome size = 1.43e+08
# band width = 300
# model fold = [5, 50]
# qvalue cutoff = 5.00e-02
# The maximum gap between significant sites is assigned as the read length/tag size.
# The minimum length of peaks is assigned as the predicted fragment length "d".
# Larger dataset will be scaled towards smaller dataset.
# Range for calculating regional lambda is: 10000 bps
# Broad region calling is off
# Paired-End mode is on
INFO @ 13 Nov 2025 15:26:39: [44 MB] #1 read fragment files...
INFO @ 13 Nov 2025 15:26:39: [44 MB] #1 read treatment fragments...
INFO @ 13 Nov 2025 15:26:44: [83 MB] 1000000 fragments parsed
INFO @ 13 Nov 2025 15:26:48: [96 MB] 2000000 fragments parsed
INFO @ 13 Nov 2025 15:26:52: [104 MB] 3000000 fragments parsed
INFO @ 13 Nov 2025 15:26:56: [115 MB] 4000000 fragments parsed
INFO @ 13 Nov 2025 15:27:01: [118 MB] 5000000 fragments parsed
INFO @ 13 Nov 2025 15:27:05: [131 MB] 6000000 fragments parsed
INFO @ 13 Nov 2025 15:27:09: [139 MB] 7000000 fragments parsed
INFO @ 13 Nov 2025 15:27:10: [142 MB] 7328238 fragments have been read.
INFO @ 13 Nov 2025 15:27:16: [142 MB] #1 mean fragment size is determined as 154.7 bp from treatment
INFO @ 13 Nov 2025 15:27:16: [142 MB] #1 fragment size = 154.7
INFO @ 13 Nov 2025 15:27:16: [142 MB] #1 total fragments in treatment: 7328238
INFO @ 13 Nov 2025 15:27:16: [142 MB] #1 user defined the maximum fragments...
INFO @ 13 Nov 2025 15:27:16: [142 MB] #1 filter out redundant fragments by allowing at most 1 identical fragment(s)
INFO @ 13 Nov 2025 15:27:28: [142 MB] #1 fragments after filtering in treatment: 7326315
INFO @ 13 Nov 2025 15:27:28: [142 MB] #1 Redundant rate of treatment: 0.00
INFO @ 13 Nov 2025 15:27:28: [142 MB] #1 finished!
INFO @ 13 Nov 2025 15:27:28: [142 MB] #2 Build Peak Model...
INFO @ 13 Nov 2025 15:27:28: [142 MB] #2 Skipped...
INFO @ 13 Nov 2025 15:27:28: [142 MB] #3 Call peaks...
INFO @ 13 Nov 2025 15:27:28: [142 MB] #3 Pre-compute pvalue-qvalue table...
INFO @ 13 Nov 2025 15:27:54: [803 MB] #3 In the peak calling step, the following will be performed simultaneously:
INFO @ 13 Nov 2025 15:27:54: [803 MB] #3 Write bedGraph files for treatment pileup (after scaling if necessary)... GFP_OE_treat_pileup.bdg
INFO @ 13 Nov 2025 15:27:54: [803 MB] #3 Write bedGraph files for control lambda (after scaling if necessary)... GFP_OE_control_lambda.bdg
INFO @ 13 Nov 2025 15:27:54: [803 MB] #3 Pileup will be based on sequencing depth in treatment.
INFO @ 13 Nov 2025 15:27:54: [803 MB] #3 Call peaks for each chromosome...
INFO @ 13 Nov 2025 15:28:25: [803 MB] #4 Write output xls file... GFP_OE_peaks.xls
INFO @ 13 Nov 2025 15:28:25: [803 MB] #4 Write peak in narrowPeak format file... GFP_OE_peaks.narrowPeak
INFO @ 13 Nov 2025 15:28:25: [803 MB] #4 Write summits bed file... GFP_OE_summits.bed
INFO @ 13 Nov 2025 15:28:25: [803 MB] Done!
INFO @ 13 Nov 2025 15:28:26: [44 MB]
# Command line: callpeak -t ../0_data/rox2_OE.final.bam -g dm -n roX2_OE --shift -100 --extsize 200 --nomodel -B -f BAMPE
# ARGUMENTS LIST:
# name = roX2_OE
# format = BAMPE
# ChIP-seq file = ['../0_data/rox2_OE.final.bam']
# control file = None
# effective genome size = 1.43e+08
# band width = 300
# model fold = [5, 50]
# qvalue cutoff = 5.00e-02
# The maximum gap between significant sites is assigned as the read length/tag size.
# The minimum length of peaks is assigned as the predicted fragment length "d".
# Larger dataset will be scaled towards smaller dataset.
# Range for calculating regional lambda is: 10000 bps
# Broad region calling is off
# Paired-End mode is on
INFO @ 13 Nov 2025 15:28:26: [44 MB] #1 read fragment files...
INFO @ 13 Nov 2025 15:28:26: [44 MB] #1 read treatment fragments...
INFO @ 13 Nov 2025 15:28:30: [84 MB] 843600 fragments have been read.
INFO @ 13 Nov 2025 15:28:30: [84 MB] #1 mean fragment size is determined as 175.2 bp from treatment
INFO @ 13 Nov 2025 15:28:30: [84 MB] #1 fragment size = 175.2
INFO @ 13 Nov 2025 15:28:30: [84 MB] #1 total fragments in treatment: 843600
INFO @ 13 Nov 2025 15:28:30: [84 MB] #1 user defined the maximum fragments...
INFO @ 13 Nov 2025 15:28:30: [84 MB] #1 filter out redundant fragments by allowing at most 1 identical fragment(s)
INFO @ 13 Nov 2025 15:28:31: [84 MB] #1 fragments after filtering in treatment: 815963
INFO @ 13 Nov 2025 15:28:31: [84 MB] #1 Redundant rate of treatment: 0.03
INFO @ 13 Nov 2025 15:28:31: [84 MB] #1 finished!
INFO @ 13 Nov 2025 15:28:31: [84 MB] #2 Build Peak Model...
INFO @ 13 Nov 2025 15:28:31: [84 MB] #2 Skipped...
INFO @ 13 Nov 2025 15:28:31: [84 MB] #3 Call peaks...
INFO @ 13 Nov 2025 15:28:31: [84 MB] #3 Pre-compute pvalue-qvalue table...
INFO @ 13 Nov 2025 15:28:35: [147 MB] #3 In the peak calling step, the following will be performed simultaneously:
INFO @ 13 Nov 2025 15:28:35: [147 MB] #3 Write bedGraph files for treatment pileup (after scaling if necessary)... roX2_OE_treat_pileup.bdg
INFO @ 13 Nov 2025 15:28:35: [147 MB] #3 Write bedGraph files for control lambda (after scaling if necessary)... roX2_OE_control_lambda.bdg
INFO @ 13 Nov 2025 15:28:35: [147 MB] #3 Pileup will be based on sequencing depth in treatment.
INFO @ 13 Nov 2025 15:28:35: [147 MB] #3 Call peaks for each chromosome...
INFO @ 13 Nov 2025 15:28:38: [147 MB] #4 Write output xls file... roX2_OE_peaks.xls
INFO @ 13 Nov 2025 15:28:38: [147 MB] #4 Write peak in narrowPeak format file... roX2_OE_peaks.narrowPeak
INFO @ 13 Nov 2025 15:28:38: [147 MB] #4 Write summits bed file... roX2_OE_summits.bed
INFO @ 13 Nov 2025 15:28:38: [147 MB] Done!
wc -l *narrowPeak
21337 GFP_OE_peaks.narrowPeak
2070 roX2_OE_peaks.narrowPeak
23407 ๆป่ฎก
total=$(samtools view -c ../0_data/GFP_OE.final.bam)
peak=$(bedtools sort -i ./GFP_OE_peaks.narrowPeak | bedtools merge -i stdin | bedtools intersect -u -nonamecheck -a ../0_data/GFP_OE.final.bam -b stdin -ubam | samtools view -c)
frip=$(bc<<<"scale=2;100*$peak/$total")
echo "GFP_OE: $frip %"
GFP_OE: 24.22 %
total=$(samtools view -c ../0_data/rox2_OE.final.bam)
peak=$(bedtools sort -i ./roX2_OE_peaks.narrowPeak | bedtools merge -i stdin | bedtools intersect -u -nonamecheck -a ../0_data/rox2_OE.final.bam -b stdin -ubam | samtools view -c)
frip=$(bc<<<"scale=2;100*$peak/$total")
echo "roX2_OE: $frip %"
roX2_OE: 16.24 %
awk 'BEGIN {OFS="\t"} {print $1, $2, $3, "", $4}' ../0_data/GFP_OE_norm.bedgraph| awk '$4 >= 50' > GFP_OE_check.bed
awk 'BEGIN {OFS="\t"} {print $1, $2, $3, "", $4}' ../0_data/rox2_OE_norm.bedgraph| awk '$4 >= 50' > roX2_OE_check.bed
intersectBed -a ./GFP_OE_peaks.narrowPeak -b ./GFP_OE_check.bed -wa |sort | uniq > GFP_OE.filteredPeak
intersectBed -a ./roX2_OE_peaks.narrowPeak -b ./roX2_OE_check.bed -wa |sort | uniq > roX2_OE.filteredPeak
macs3 bdgdiff --t1 ./GFP_OE_treat_pileup.bdg --c1 ./GFP_OE_control_lambda.bdg --t2 ./roX2_OE_treat_pileup.bdg --c2 ./roX2_OE_control_lambda.bdg --o-prefix diffpeak
INFO @ 13 Nov 2025 15:30:27: [43 MB] Read and build treatment 1 bedGraph...
INFO @ 13 Nov 2025 15:30:40: [134 MB] Read and build control 1 bedGraph...
INFO @ 13 Nov 2025 15:30:56: [251 MB] Read and build treatment 2 bedGraph...
INFO @ 13 Nov 2025 15:30:58: [262 MB] Read and build control 2 bedGraph...
INFO @ 13 Nov 2025 15:31:49: [858 MB] Write peaks...
INFO @ 13 Nov 2025 15:31:49: [858 MB] Done
intersectBed -a ./diffpeak_c3.0_cond1.bed -b ./GFP_OE_check.bed -wa |sort |uniq > GFP_OE_high.filteredPeak
intersectBed -a ./diffpeak_c3.0_cond2.bed -b ./roX2_OE_check.bed -wa |sort |uniq > roX2_OE_high.filteredPeak
annotatePeaks.pl ./GFP_OE_high.filteredPeak mm10 > GFP_high.csv
annotatePeaks.pl ./roX2_OE_high.filteredPeak mm10 > roX2_high.csv
Peak file = ./GFP_OE_high.filteredPeak
Genome = mm10
Organism = mouse
Peak/BED file conversion summary:
BED/Header formatted lines: 7154
peakfile formatted lines: 0
Duplicated Peak IDs: 0
Peak File Statistics:
Total Peaks: 7154
Redundant Peak IDs: 0
Peaks lacking information: 0 (need at least 5 columns per peak)
Peaks with misformatted coordinates: 0 (should be integer)
Peaks with misformatted strand: 0 (should be either +/- or 0/1)
Peak file looks good!
Reading Positions...
-----------------------
offset=0
Finding Closest TSS...
Annotating:...
Annotation Number of peaks Total size (bp) Log2 Ratio (obs/exp) LogP enrichment (+values depleted)
3UTR 4.0 2261924 -0.814 1.776
miRNA 0.0 1572 -0.007 0.005
ncRNA 0.0 440273 -1.245 1.369
TTS 17.0 3209804 0.769 -3.647
pseudo 1.0 112683 1.513 -1.219
Exon 12.0 3597618 0.102 -0.815
Intron 210.0 104460498 -0.629 32.352
Intergenic 1043.0 299951322 0.162 -27.584
Promoter 11.0 3534405 0.002 -0.618
5UTR 1.0 295082 0.125 -0.510
NOTE: If this part takes more than 2 minutes, there is a good chance
your machine ran out of memory: consider hitting ctrl+C and rerunning
the command with "-noann"
To capture annotation stats in a file, use "-annStats <filename>" next time
Annotating:...
Annotation Number of peaks Total size (bp) Log2 Ratio (obs/exp) LogP enrichment (+values depleted)
3UTR 4.0 2261924 -0.813 1.773
Other 2.0 1955102 -1.603 2.842
RC? 0.0 1630 -0.007 0.005
RNA 0.0 14251 -0.063 0.044
miRNA 0.0 1572 -0.007 0.005
ncRNA 0.0 440273 -1.244 1.369
TTS 17.0 3209804 0.769 -3.651
LINE 335.0 111932786 -0.054 1.507
LINE? 0.0 676 -0.003 0.002
srpRNA 0.0 5924 -0.026 0.018
SINE 77.0 25041054 -0.015 0.708
RC 0.0 8253 -0.037 0.026
tRNA 0.0 32296 -0.138 0.100
DNA? 0.0 17074 -0.075 0.053
pseudo 1.0 112683 1.514 -1.219
DNA 17.0 3488124 0.650 -3.007
Exon 12.0 3597618 0.102 -0.816
Intron 124.0 61231934 -0.618 17.457
Intergenic 506.0 128425146 0.343 -22.457
Promoter 11.0 3534405 0.002 -0.619
5UTR 1.0 295082 0.125 -0.510
LTR? 0.0 25957 -0.112 0.081
scRNA 0.0 99626 -0.389 0.310
CpG-Island 0.0 344607 -1.051 1.071
Low_complexity 5.0 2951732 -0.875 2.255
LTR 175.0 58417076 -0.053 1.145
Simple_repeat 11.0 8091972 -1.193 6.725
snRNA 0.0 32747 -0.140 0.102
Unknown 1.0 1294779 -2.008 2.413
SINE? 0.0 4205 -0.019 0.013
Satellite 0.0 1200921 -2.245 3.737
rRNA 0.0 24604 -0.106 0.076
Counting Tags in Peaks from each directory...
Organism: mouse
Loading Gene Informaiton...
Outputing Annotation File...
Done annotating peaks file
Peak file = ./roX2_OE_high.filteredPeak
Genome = mm10
Organism = mouse
Peak/BED file conversion summary:
BED/Header formatted lines: 2
peakfile formatted lines: 0
Duplicated Peak IDs: 0
Peak File Statistics:
Total Peaks: 2
Redundant Peak IDs: 0
Peaks lacking information: 0 (need at least 5 columns per peak)
Peaks with misformatted coordinates: 0 (should be integer)
Peaks with misformatted strand: 0 (should be either +/- or 0/1)
Peak file looks good!
Reading Positions...
-----------------------
offset=0
Finding Closest TSS...
Annotating:.
Annotation Number of peaks Total size (bp) Log2 Ratio (obs/exp) LogP enrichment (+values depleted)
3UTR 0.0 912091 -0.008 0.005
miRNA 0.0 1565 -0.000 0.000
ncRNA 0.0 176408 -0.001 0.001
TTS 0.0 1271936 -0.011 0.007
pseudo 0.0 49137 -0.000 0.000
Exon 0.0 1345645 -0.011 0.008
Intron 0.0 42814874 -0.417 0.289
Intergenic 1.0 122614479 0.477 -0.331
Promoter 0.0 1381821 -0.012 0.008
5UTR 0.0 113196 -0.001 0.001
NOTE: If this part takes more than 2 minutes, there is a good chance
your machine ran out of memory: consider hitting ctrl+C and rerunning
the command with "-noann"
To capture annotation stats in a file, use "-annStats <filename>" next time
Annotating:.
Annotation Number of peaks Total size (bp) Log2 Ratio (obs/exp) LogP enrichment (+values depleted)
3UTR 0.0 912091 -0.008 0.005
Other 0.0 680155 -0.006 0.004
RC? 0.0 551 -0.000 0.000
RNA 0.0 7041 -0.000 0.000
miRNA 0.0 1565 -0.000 0.000
ncRNA 0.0 176408 -0.001 0.001
TTS 0.0 1271936 -0.011 0.007
LINE 0.0 58384850 -0.603 0.418
LINE? 0.0 252 -0.000 0.000
srpRNA 0.0 2237 -0.000 0.000
SINE 0.0 9603004 -0.083 0.058
RC 0.0 3592 -0.000 0.000
tRNA 0.0 16844 -0.000 0.000
DNA? 0.0 9487 -0.000 0.000
pseudo 0.0 49137 -0.000 0.000
DNA 0.0 1615643 -0.014 0.009
Exon 0.0 1345645 -0.011 0.008
Intron 0.0 23504225 -0.213 0.148
Intergenic 1.0 46586251 1.875 -1.300
Promoter 0.0 1381821 -0.012 0.008
5UTR 0.0 113196 -0.001 0.001
LTR? 0.0 13679 -0.000 0.000
scRNA 0.0 35595 -0.000 0.000
CpG-Island 0.0 100760 -0.001 0.001
Low_complexity 0.0 1019307 -0.009 0.006
LTR 0.0 21103798 -0.190 0.132
Simple_repeat 0.0 2623670 -0.022 0.015
snRNA 0.0 16730 -0.000 0.000
Unknown 0.0 89653 -0.001 0.001
SINE? 0.0 1305 -0.000 0.000
Satellite 0.0 199408 -0.002 0.001
rRNA 0.0 17021 -0.000 0.000
Counting Tags in Peaks from each directory...
Organism: mouse
Loading Gene Informaiton...
Outputing Annotation File...
Done annotating peaks file
echo `fastp --version`
echo `bowtie2 --version`
echo `samtools --version`
echo `sambamba --version`
echo `bedtools --version`
echo `fastqc --version`
echo `multiqc --version`
echo `macs3 --version`
echo `deeptools --version`
echo `homer --version`
fastp 0.23.4
/home/yhli/miniconda3/bin/bowtie2-align-s version 2.5.4 64-bit Built on fv-az356-861 Tue Jun 11 00:21:46 UTC 2024 Compiler: gcc version 12.3.0 (conda-forge gcc 12.3.0-7) Options: -O3 -msse2 -funroll-loops -g3 -fvisibility-inlines-hidden -fmessage-length=0 -march=nocona -mtune=haswell -ftree-vectorize -fPIC -fstack-protector-strong -fno-plt -O2 -ffunction-sections -pipe -isystem /home/yhli/miniconda3/include -fdebug-prefix-map=/opt/conda/conda-bld/bowtie2_1718065018344/work=/usr/local/src/conda/bowtie2-2.5.4 -fdebug-prefix-map=/home/yhli/miniconda3=/usr/local/src/conda-prefix -O3 Sizeof {int, long, long long, void*, size_t, off_t}: {4, 8, 8, 8, 8, 8}
samtools 1.20 Using htslib 1.20 Copyright (C) 2024 Genome Research Ltd. Samtools compilation details: Features: build=configure curses=yes CC: /opt/conda/conda-bld/samtools_1720645213030/_build_env/bin/x86_64-conda-linux-gnu-cc CPPFLAGS: -DNDEBUG -D_FORTIFY_SOURCE=2 -O2 -isystem /home/yhli/miniconda3/include CFLAGS: -Wall -march=nocona -mtune=haswell -ftree-vectorize -fPIC -fstack-protector-strong -fno-plt -O2 -ffunction-sections -pipe -isystem /home/yhli/miniconda3/include -fdebug-prefix-map=/opt/conda/conda-bld/samtools_1720645213030/work=/usr/local/src/conda/samtools-1.20 -fdebug-prefix-map=/home/yhli/miniconda3=/usr/local/src/conda-prefix LDFLAGS: -Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now -Wl,--disable-new-dtags -Wl,--gc-sections -Wl,--allow-shlib-undefined -Wl,-rpath,/home/yhli/miniconda3/lib -Wl,-rpath-link,/home/yhli/miniconda3/lib -L/home/yhli/miniconda3/lib HTSDIR: LIBS: CURSES_LIB: -ltinfow -lncursesw HTSlib compilation details: Features: build=configure libcurl=yes S3=yes GCS=yes libdeflate=yes lzma=yes bzip2=yes plugins=yes plugin-path=/home/yhli/miniconda3/libexec/htslib htscodecs=1.6.0 CC: /opt/conda/conda-bld/htslib_1720639468368/_build_env/bin/x86_64-conda-linux-gnu-cc CPPFLAGS: -DNDEBUG -D_FORTIFY_SOURCE=2 -O2 -isystem /home/yhli/miniconda3/include CFLAGS: -Wall -march=nocona -mtune=haswell -ftree-vectorize -fPIC -fstack-protector-strong -fno-plt -O2 -ffunction-sections -pipe -isystem /home/yhli/miniconda3/include -fdebug-prefix-map=/opt/conda/conda-bld/htslib_1720639468368/work=/usr/local/src/conda/htslib-1.20 -fdebug-prefix-map=/home/yhli/miniconda3=/usr/local/src/conda-prefix -fvisibility=hidden LDFLAGS: -Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now -Wl,--disable-new-dtags -Wl,--gc-sections -Wl,--allow-shlib-undefined -Wl,-rpath,/home/yhli/miniconda3/lib -Wl,-rpath-link,/home/yhli/miniconda3/lib -L/home/yhli/miniconda3/lib -fvisibility=hidden -rdynamic HTSlib URL scheme handlers present: built-in: preload, data, file libcurl: imaps, pop3, gophers, http, smb, gopher, sftp, ftps, imap, smtp, wss, ws, smtps, rtsp, scp, ftp, telnet, mqtt, https, smbs, tftp, pop3s, dict Google Cloud Storage: gs+http, gs+https, gs Amazon S3: s3+https, s3+http, s3 S3 Multipart Upload: s3w, s3w+https, s3w+http crypt4gh-needed: crypt4gh mem: mem
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
sambamba 1.0.1
by Artem Tarasov and Pjotr Prins (C) 2012-2023
LDC 1.38.0 / DMD v2.108.1 / LLVM17.0.6 / bootstrap LDC - the LLVM D compiler (1.38.0)
bedtools v2.31.1
FastQC v0.12.1
multiqc, version 1.17
macs3 3.0.2
deeptools 3.5.5
homer : Empirical Motif Optimizer
usage: ./homer [data] [parameters] -a [action]
This program is meant to be called from other programs (i.e. findMotifsGenome.pl), and not used directly
Data options:
-dna|-prot : Sequence type (-dna)
-s <file> : Sequence File
-g <file> : Group/Stat File
-mer <file> : Mer File
-m <file> : PSSM Motif File
-o <file> : output file prefix
-seed <file> : seed file
-offset <#> : offset of sequence from TSS (-2000)
Parameter options:
-exact : remember mapping between mers and genes (default: approx)
-w : Weight sequences (according to addition columns in group file: 1st-gene 2nd-sequence)
-T : Test all sequences as candidate motifs (default: only test target sequences)
-noautoscale : Do not autoscale sequences to be equal in foreground and background
-freqAdjust : Compute log-odds using frequency, default (0.25)
-dual : find dual motifs in the form A<gap>B where A and B can be rev-opposites
-flip : find dual motifs in the form A<gap>B or B<gap>A
-zoopsapprox <OFF,#(max to count)> : (counts multiple motifs per sequence | default: 2)
-norevopp : don't search opposite strand (default->DNA:yes, Protein:no)
-min <#> : min mer size (6)
-max <#> : max mer size [also standard mer size] (10)
-len <#> : Find motifs of length # (default=10)
-gap <#,#,#-#> : Find motifs with gaps(0)(i.e. -gap 3 -gap 2,4,5 -gap 1-10
Gaps will only be in the center of motif and will only use even lengthed motifs
-mis <#> : # of mismatches to check for degeneracy (1)
-IUPAC <#> : # of IUPAC codes per mer that can be used during global optimization (0)
-iupactype <1,2,or3> : Type of IUPAC symbols used
1: (default) Only N is used
2: Only N and 2 bp symbols are used (i.e. R = A or G
3: Full IUPAC code is used (includes 3-way symbols)
-S <#> : number of seeds to check during profile optimization(50)
-branch <#> : sets depth of optimization (closer to zero the more sensitive (0.5))
-I <#> : maximum number of iterations during optimization (5)
-rmalign : DO NOT remove aligned seeds
-maxneg <0 to 1> maximum percentage of negative genes that can contain the motif
-speed <NORMAL|FAST>: Program will heuristically avoid performing exhaustive
calculations (default: FAST)
Scoring Functions:
-alg <method> : scoring algorithm (default: hypergeo)
hypergeo - hypergeometric scoring (ZOOPS)
binomial - binomical scoring [for variable length seq] (ZOOPS) (requires exact)
approxbinomial - binomical scoring [for variable length seq] (ZOOPS) (requires exact)
sitehypergeo - hypergeometric scoring across seq positions (very slow)
sitebinomial - binomial scoring across seq positions
fisher <#> - fisher exact test (slow, # scales exponentially)
<# = largest repetition to consider [default=2]>
rank - group file must have sortable numeric value
freqdiff - used by most bayesian/nnet programs
logit - used by most bayesian/nnet programs
Background Modeling options (this forces a binomial style scoring function):
-b <method> [method options...]
markov <#> - generate hmm from target sequences using a hmm of order #
bmarkov <#> - generate hmm from background sequences using a hmm of order #
mosaic - generate mosaic hmm from background sequences **coming soon**
Filter Options:
-N <float> : filtering cutoff for ratio of N's in sequence (0.9)
-seqless <#> : filter sequences shorter than #
-seqmore <#> : filter sequences longer than #
Actions (-a):
MOTIFS - Find motifs <outfile>.motifs# where # = motif length
MERS - Create mer file (low memory) <stdout>
DMERS - Create degenerate mer file <stdout>
FIND - find motifs in sequence <stdout>
OPTPVALUE - optimize motif threshold and pvalue (exact)<stdout>
GETPVALUE - get the p-value enrichment for a given motif(exact)<stdout>
GENESCORE - returns highest motif score for each gene <stdout>
REFINE - optimize motif PSSM profile, threshold, and pvalue <stdout>
REFINETHRESH - optimize motif PSSM threshold and pvalue <stdout>
CLUSTER - cluster mers from seed file (can't use exact scoring) <outfile>
SORTMERS - sort a mer file according to pvalue <stdout>
REMOVE - removes motif from sequence (replaces with N's) <stdout>
This program is meant to be called from other programs (i.e. findMotifsGenome.pl), and not used directly
fastp
Shifu Chen. 2023. Ultrafast one-pass FASTQ data preprocessing, quality control, and deduplication using fastp. iMeta 2: e107. https://doi.org/10.1002/imt2.107
Shifu Chen, Yanqing Zhou, Yaru Chen, Jia Gu; fastp: an ultra-fast all-in-one FASTQ preprocessor, Bioinformatics, Volume 34, Issue 17, 1 September 2018, Pages i884โi890, https://doi.org/10.1093/bioinformatics/bty560
multiqc
Ewels P, Magnusson M, Lundin S, Kรคller M. MultiQC: summarize analysis results for multiple tools and samples in a single report. Bioinformatics. 2016;32(19):3047-3048. doi:10.1093/bioinformatics/btw354
bowtie2
Langmead, B., Salzberg, S. Fast gapped-read alignment with Bowtie 2. Nat Methods 9, 357โ359 (2012). https://doi.org/10.1038/nmeth.1923
samtools
Li H, Handsaker B, Wysoker A, et al. The Sequence Alignment/Map format and SAMtools. Bioinformatics. 2009;25(16):2078-2079. doi:10.1093/bioinformatics/btp352
sambamba
Tarasov A, Vilella AJ, Cuppen E, Nijman IJ, Prins P. Sambamba: fast processing of NGS alignment formats. Bioinformatics. 2015;31(12):2032-2034. doi:10.1093/bioinformatics/btv098
bedtools
Quinlan AR, Hall IM. BEDTools: a flexible suite of utilities for comparing genomic features. Bioinformatics. 2010;26(6):841-842. doi:10.1093/bioinformatics/btq033
hg38-blacklist.v2
Amemiya, H.M., Kundaje, A. & Boyle, A.P. The ENCODE Blacklist: Identification of Problematic Regions of the Genome. Sci Rep 9, 9354 (2019). https://doi.org/10.1038/s41598-019-45839-z
macs3
Zhang, Y., Liu, T., Meyer, C.A. et al. Model-based Analysis of ChIP-Seq (MACS). Genome Biol 9, R137 (2008). https://doi.org/10.1186/gb-2008-9-9-r137
deeptools
Ramรญrez F, Ryan DP, Grรผning B, et al. deepTools2: a next generation web server for deep-sequencing data analysis. Nucleic Acids Res. 2016;44(W1):W160-W165. doi:10.1093/nar/gkw257
meme Suite
Bailey TL, Johnson J, Grant CE, Noble WS. The MEME Suite. Nucleic Acids Res. 2015;43(W1):W39-W49. doi:10.1093/nar/gkv416
WashU Epigenome browser
Li D, Purushotham D, Harrison JK, et al. WashU Epigenome Browser update 2022. Nucleic Acids Res. 2022;50(W1):W774-W781. doi:10.1093/nar/gkac238